import React, { useState, useEffect } from 'react';
import { switchToMockApi, switchToRealApi, checkServerStatus } from '../services/api';

export default function ApiModeSwitch() {
    const [isMockMode, setIsMockMode] = useState(false);
    const [isChecking, setIsChecking] = useState(false);
    const [showNotification, setShowNotification] = useState(false);
    const [notification, setNotification] = useState({ message: '', type: 'info' });

    // 组件加载时检查服务器状态
    useEffect(() => {
        const checkStatus = async () => {
            setIsChecking(true);
            const isServerUp = await checkServerStatus();
            setIsMockMode(!isServerUp);
            setIsChecking(false);
        };

        checkStatus();
    }, []);

    // 切换API模式
    const handleToggleMode = async () => {
        setIsChecking(true);

        if (isMockMode) {
            // 尝试切换回真实API
            const isServerUp = await switchToRealApi();
            if (isServerUp) {
                setIsMockMode(false);
                showNotificationMessage('已切换到真实API模式', 'success');
            } else {
                showNotificationMessage('服务器连接失败，继续使用模拟数据', 'warning');
            }
        } else {
            // 切换到模拟API
            switchToMockApi();
            setIsMockMode(true);
            showNotificationMessage('已切换到模拟API模式', 'info');
        }

        setIsChecking(false);
    };

    // 显示通知消息
    const showNotificationMessage = (message, type) => {
        setNotification({ message, type });
        setShowNotification(true);

        // 3秒后自动隐藏通知
        setTimeout(() => {
            setShowNotification(false);
        }, 3000);
    };

    return (
        <div className='api-mode-switch'>
            <div className='d-flex align-items-center'>
                <div className='form-check form-switch me-2'>
                    <input
                        className='form-check-input'
                        type='checkbox'
                        id='apiModeToggle'
                        checked={isMockMode}
                        onChange={handleToggleMode}
                        disabled={isChecking}
                    />
                    <label className='form-check-label' htmlFor='apiModeToggle'>
                        {isChecking ? '检查中...' : isMockMode ? '模拟API模式' : '真实API模式'}
                    </label>
                </div>
                {isMockMode && <span className='badge bg-warning text-dark'>使用本地模拟数据</span>}
                {!isMockMode && <span className='badge bg-success'>已连接到后端服务器</span>}
            </div>

            {showNotification && (
                <div className={`alert alert-${notification.type} mt-2 py-2 px-3`} style={{ fontSize: '0.85rem' }}>
                    {notification.message}
                </div>
            )}
        </div>
    );
}
